# API Reference

## hNMF.model

::: hnmf.model.HierarchicalNMF
    options:
      members: true
      show_source: true
      heading_level: 3
      summary: true
      filters:
        - public

## hNMF.helpers

::: hnmf.helpers
    options:
      heading_level: 3
      filters:
        - "!^_[^_]"
        - "!_$"